Enum TrieResult

enum TrieResult

An enum representing the return value from a lookup in Char16Trie.

Variants

NoMatch

The input unit(s) did not continue a matching string. Once next() returns TrieResult::NoMatch, all further calls to next() will also return TrieResult::NoMatch.

NoValue

The input unit(s) matched a string but there is no value for the string so far. (It is a prefix of a longer string.)

FinalValue(i32)

The input unit(s) continued a matching string and there is a value for the string so far. No further input byte/unit can continue a matching string.

Intermediate(i32)

The input unit(s) continued a matching string and there is a value for the string so far. Another input byte/unit can continue a matching string.

Implementations

impl Clone for TrieResult

fn clone(self: &Self) -> TrieResult

impl Copy for TrieResult

impl Debug for TrieResult

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for TrieResult

impl PartialEq for TrieResult

fn eq(self: &Self, other: &TrieResult) -> bool

impl RefUnwindSafe for TrieResult

impl Send for TrieResult

impl StructuralPartialEq for TrieResult

impl Sync for TrieResult

impl Unpin for TrieResult

impl UnsafeUnpin for TrieResult

impl UnwindSafe for TrieResult

impl<T> Any for TrieResult

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TrieResult

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TrieResult

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TrieResult

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for TrieResult

impl<T> From for TrieResult

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for TrieResult

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for TrieResult

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TrieResult

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TrieResult

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>