Struct Char16Trie

struct Char16Trie<'data> { ... }

This struct represents a de-serialized Char16Trie that was exported from ICU binary data.

Light-weight, non-const reader class for a CharsTrie. Traverses a char-serialized data structure with minimal state, for mapping 16-bit-unit sequences to non-negative integer values.

For more information:

Implementations

impl<'data> Char16Trie<'data>

fn new(data: ZeroVec<'data, u16>) -> Self

Returns a new Char16Trie with ownership of the provided data.

fn iter(self: &Self) -> Char16TrieIterator<'_>

Returns a new Char16TrieIterator backed by borrowed data from the trie data

impl<'data> Clone for Char16Trie<'data>

fn clone(self: &Self) -> Char16Trie<'data>

impl<'data> Debug for Char16Trie<'data>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'data> Eq for Char16Trie<'data>

impl<'data> Freeze for Char16Trie<'data>

impl<'data> PartialEq for Char16Trie<'data>

fn eq(self: &Self, other: &Char16Trie<'data>) -> bool

impl<'data> RefUnwindSafe for Char16Trie<'data>

impl<'data> Send for Char16Trie<'data>

impl<'data> StructuralPartialEq for Char16Trie<'data>

impl<'data> Sync for Char16Trie<'data>

impl<'data> Unpin for Char16Trie<'data>

impl<'data> UnsafeUnpin for Char16Trie<'data>

impl<'data> UnwindSafe for Char16Trie<'data>

impl<'zf, 'zf_inner> ZeroFrom for Char16Trie<'zf>

fn zero_from(this: &'zf Char16Trie<'zf_inner>) -> Self

impl<T> Any for Char16Trie<'data>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Char16Trie<'data>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Char16Trie<'data>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Char16Trie<'data>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for Char16Trie<'data>

impl<T> From for Char16Trie<'data>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Char16Trie<'data>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Char16Trie<'data>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Char16Trie<'data>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Char16Trie<'data>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>