Enum InvalidStringList
enum InvalidStringList
Custom Errors for CodePointInversionListAndStringList.
Variants
-
InvalidStringLength() A string in the string list had an invalid length
-
StringListNotUnique() A string in the string list appears more than once
-
StringListNotSorted() Two strings in the string list compare to each other opposite of sorted order
Implementations
impl Debug for InvalidStringList
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for InvalidStringList
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl Freeze for InvalidStringList
impl RefUnwindSafe for InvalidStringList
impl Send for InvalidStringList
impl Sync for InvalidStringList
impl Unpin for InvalidStringList
impl UnsafeUnpin for InvalidStringList
impl UnwindSafe for InvalidStringList
impl<T> Any for InvalidStringList
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for InvalidStringList
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for InvalidStringList
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for InvalidStringList
impl<T> From for InvalidStringList
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for InvalidStringList
fn to_string(self: &Self) -> String
impl<T, U> Into for InvalidStringList
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for InvalidStringList
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for InvalidStringList
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>