Struct CodePointMapRange

struct CodePointMapRange<T> { ... }

Represents a range of consecutive code points sharing the same value in a code point map.

The start and end of the interval is represented as a RangeInclusive<u32>, and the value is represented as T.

Fields

range: RangeInclusive<u32>

Range of code points from start to end (inclusive).

value: T

Trie value associated with this range.

Implementations

impl<T> Any for CodePointMapRange<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for CodePointMapRange<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for CodePointMapRange<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for CodePointMapRange<T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for CodePointMapRange<T>

impl<T> Freeze for CodePointMapRange<T>

impl<T> From for CodePointMapRange<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for CodePointMapRange<T>

impl<T> Send for CodePointMapRange<T>

impl<T> StructuralPartialEq for CodePointMapRange<T>

impl<T> Sync for CodePointMapRange<T>

impl<T> ToOwned for CodePointMapRange<T>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> Unpin for CodePointMapRange<T>

impl<T> UnsafeUnpin for CodePointMapRange<T>

impl<T> UnwindSafe for CodePointMapRange<T>

impl<T, U> Into for CodePointMapRange<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for CodePointMapRange<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for CodePointMapRange<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::clone::Clone> Clone for CodePointMapRange<T>

fn clone(self: &Self) -> CodePointMapRange<T>

impl<T: $crate::cmp::Eq> Eq for CodePointMapRange<T>

impl<T: $crate::cmp::PartialEq> PartialEq for CodePointMapRange<T>

fn eq(self: &Self, other: &CodePointMapRange<T>) -> bool

impl<T: $crate::fmt::Debug> Debug for CodePointMapRange<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result