Struct CodePointInversionListAndStringList
struct CodePointInversionListAndStringList<'data> { ... }
A data structure providing a concrete implementation of a set of code points and strings, using an inversion list for the code points.
This is what ICU4C calls a UnicodeSet.
Implementations
impl<'data> CodePointInversionListAndStringList<'data>
fn try_from(cp_inv_list: CodePointInversionList<'data>, str_list: VarZeroVec<'data, str>) -> Result<Self, InvalidStringList>Returns a new
CodePointInversionListAndStringListfrom both aCodePointInversionListfor the code points and aVarZeroVec<str>of strings.fn size(self: &Self) -> usizeReturns the number of elements in this set (its cardinality). Note than the elements of a set may include both individual codepoints and strings.
fn has_strings(self: &Self) -> boolReturn true if this set contains multi-code point strings or the empty string.
fn contains_str(self: &Self, s: &str) -> boolExamples
use CodePointInversionList; use CodePointInversionListAndStringList; use VarZeroVec; let cp_slice = &; let cp_list = try_from_u32_inversion_list_slice.unwrap; let str_slice = &; let str_list = from; let cpilsl = try_from.unwrap; assert!; assert!; assert!; assert!; // U+1254 ETHIOPIC SYLLABLE QHEE assert!;fn contains32(self: &Self, cp: u32) -> boolExamples
use CodePointInversionList; use CodePointInversionListAndStringList; use VarZeroVec; let cp_slice = &; let cp_list = try_from_u32_inversion_list_slice.unwrap; let str_slice = &; let str_list = from; let cpilsl = try_from.unwrap; assert!; assert!; assert!;fn contains(self: &Self, ch: char) -> boolExamples
use CodePointInversionList; use CodePointInversionListAndStringList; use VarZeroVec; let cp_slice = &; let cp_list = try_from_u32_inversion_list_slice.unwrap; let str_slice = &; let str_list = from; let cpilsl = try_from.unwrap; assert!; assert!; // U+1254 ETHIOPIC SYLLABLE QHEE assert!; assert!; // U+1FA2B NEUTRAL CHESS TURNED QUEENfn code_points(self: &Self) -> &CodePointInversionList<'data>Access the underlying
CodePointInversionList.fn strings(self: &Self) -> &VarZeroSlice<str>Access the contained strings.
impl<'a> Yokeable for CodePointInversionListAndStringList<'static>
fn transform(self: &'a Self) -> &'a <Self as >::Outputfn transform_owned(self: Self) -> <Self as >::Outputunsafe fn make(this: <Self as >::Output) -> Selffn transform_mut<F>(self: &'a mut Self, f: F) where F: 'static + for<'b> FnOnce(&'b mut <Self as >::Output)
impl<'data> Clone for CodePointInversionListAndStringList<'data>
fn clone(self: &Self) -> CodePointInversionListAndStringList<'data>
impl<'data> Debug for CodePointInversionListAndStringList<'data>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'data> EncodeAsVarULE for CodePointInversionListAndStringList<'data>
fn encode_var_ule_as_slices<R, impl FnOnce(&[&[u8]]) -> R: FnOnce(&[&[u8]]) -> R>(self: &Self, cb: impl FnOnce(&[&[u8]]) -> R) -> Rfn encode_var_ule_len(self: &Self) -> usizefn encode_var_ule_write(self: &Self, dst: &mut [u8])
impl<'data> Eq for CodePointInversionListAndStringList<'data>
impl<'data> Freeze for CodePointInversionListAndStringList<'data>
impl<'data> From for CodePointInversionListAndStringList<'data>
fn from(other: &'data CodePointInversionListAndStringListULE) -> Self
impl<'data> PartialEq for CodePointInversionListAndStringList<'data>
fn eq(self: &Self, other: &CodePointInversionListAndStringList<'data>) -> bool
impl<'data> RefUnwindSafe for CodePointInversionListAndStringList<'data>
impl<'data> Send for CodePointInversionListAndStringList<'data>
impl<'data> StructuralPartialEq for CodePointInversionListAndStringList<'data>
impl<'data> Sync for CodePointInversionListAndStringList<'data>
impl<'data> Unpin for CodePointInversionListAndStringList<'data>
impl<'data> UnsafeUnpin for CodePointInversionListAndStringList<'data>
impl<'data> UnwindSafe for CodePointInversionListAndStringList<'data>
impl<'data> ZeroFrom for CodePointInversionListAndStringList<'data>
fn zero_from(other: &'data CodePointInversionListAndStringListULE) -> Self
impl<'zf, 'zf_inner> ZeroFrom for CodePointInversionListAndStringList<'zf>
fn zero_from(this: &'zf CodePointInversionListAndStringList<'zf_inner>) -> Self
impl<T> Any for CodePointInversionListAndStringList<'data>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for CodePointInversionListAndStringList<'data>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for CodePointInversionListAndStringList<'data>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for CodePointInversionListAndStringList<'data>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> ErasedDestructor for CodePointInversionListAndStringList<'data>
impl<T> From for CodePointInversionListAndStringList<'data>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for CodePointInversionListAndStringList<'data>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for CodePointInversionListAndStringList<'data>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for CodePointInversionListAndStringList<'data>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for CodePointInversionListAndStringList<'data>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>